==> browserify-test-2.1.0.tgz: package/lib/cli.js <==
#!/usr/bin/env node
'use strict';

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _subarg = require('subarg');

var _subarg2 = _interopRequireDefault(_subarg);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

var _ = require('./');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i]; return arr2; } else { return Array.from(arr); } }

// cli

_commander2.default.version(_package2.default.version).usage('[options] [./test/*.js ...]').option('-w, --watch', 'run watch server on http://localhost:7357').option('-t, --transform <t1,t2,..>', 'add browserify transforms').parse(process.argv);

// prepare files

var argv = (0, _subarg2.default)(process.argv.slice(2), {
  alias: { t: 'transform', w: 'watch' },
  boolean: ['watch']
});
var files = [];
void (argv._ || ['./test/*.js']).forEach(function (p) {
  files.push.apply(files, _toConsumableArray(_glob2.default.sync(p)));
});

// parse transforms

var transform = [];
if (argv.transform) {
  if (!Array.isArray(argv.transform)) argv.transform = [argv.transform];
  argv.transform.forEach(function (tr) {
    if (typeof tr === 'string') {
      transform.push(tr);
    } else if (Array.isArray(tr._)) {
      transform.push([tr._[0], (0, _lodash2.default)(tr, '_')]);
    } else {
      throw new Error('invalid --transform value: ' + JSON.stringify(tr));
    }
  });
}

// run testem

(0, _2.default)({
  transform: transform, files: files,
  watch: _commander2.default.watch || false
});

==> browserify-test-2.1.1.tgz: package/lib/cli.js <==
#!/usr/bin/env node
'use strict';

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _subarg = require('subarg');

var _subarg2 = _interopRequireDefault(_subarg);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

var _ = require('./');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i]; return arr2; } else { return Array.from(arr); } }

// cli

_commander2.default.version(_package2.default.version).usage('[options] [./test/*.js ...]').option('-w, --watch', 'run watch server on http://localhost:7357').option('-t, --transform <t1,t2,..>', 'add browserify transforms').parse(process.argv);

// prepare files

var argv = (0, _subarg2.default)(process.argv.slice(2), {
  alias: { t: 'transform', w: 'watch' },
  boolean: ['watch']
});
var files = [];
if (!argv._.length) argv._ = ['./test/*.js'];
argv._.forEach(function (p) {
  return files.push.apply(files, _toConsumableArray(_glob2.default.sync(p)));
});

// parse transforms

var transform = [];
if (argv.transform) {
  if (!Array.isArray(argv.transform)) argv.transform = [argv.transform];
  argv.transform.forEach(function (tr) {
    if (typeof tr === 'string') {
      transform.push(tr);
    } else if (Array.isArray(tr._)) {
      transform.push([tr._[0], (0, _lodash2.default)(tr, '_')]);
    } else {
      throw new Error('invalid --transform value: ' + JSON.stringify(tr));
    }
  });
}

// run testem

(0, _2.default)({
  transform: transform, files: files,
  watch: _commander2.default.watch || false
});
